import * as React from 'react';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemIcon from '@mui/material/ListItemIcon';
import ListItemText from '@mui/material/ListItemText';
import CoolCheckbox from "./styled/CoolCheckbox";

const TASKS = [
  {
    id: 0,
    name: `Download the project archive for this lab and run yarn install and npm run dev.`
  },
  {
    id: 1,
    name: `Create a blue button using Styled Components in components/styled/BlueButton.jsx.`
  },
  {
    id: 2,
    name: `Create a green button using CSS modules in components/vanilla/GreenButton.jsx. Add the corresponding CSS
    module in the same directory.`
  },
  {
    id: 3,
    name: `Make the welcome message of the pages/index.jsx page component bold using inline styling.`
  },
  {
    id: 4,
    name: `Integrate the global styling written in the styles/globals.css file into the app and remove the horizontal and top padding.`
  },
  {
    id: 5,
    name: `Create a free Flagsmith account, set up a fictive organisation and a project called Lab 7.`
  },
  {
    id: 6,
    name: `Create a feature in the Development environment called button_color. Create two variations. Give a default
    value to the control state and suggestive values to the variations (these values should describe the button colours).
    The weighting should be 50-50 (the control value should have weight 0).`
  },
  {
    id: 7,
    name: `Write your environment id and place the user identification code in pages/_app.jsx.`
  },
  {
    id: 8,
    name: `Conditionally display the See Tasks button in pages/index.jsx. If the button_color feature flag is disabled,
    it should be a DangerousButton. Conversely, the button should be a GreenButton or BlueButton depending on the
    feature flag value.`
  },
  {
    id: 9,
    name: `Observe how the button changes when you start identifying new users. Check the Users table in the Flagsmith
    dashboard as well.`
  },
];

export default function TasksList() {
  const [checked, setChecked] = React.useState([TASKS[0].id]);

  const handleToggle = (id) => () => {
    const currentIndex = checked.indexOf(id);
    const newChecked = [...checked];

    if (currentIndex === -1) {
      newChecked.push(id);
    } else {
      newChecked.splice(currentIndex, 1);
    }

    setChecked(newChecked);
  };

  return (
    <List sx={{ width: '100%', bgcolor: 'background.paper' }}>
      {TASKS.map((task) => {
        const labelId = `checkbox-list-label-${task.id}`;
        return (
          <ListItem key={task.id} disablePadding>
            <ListItemButton onClick={handleToggle(task.id)}>
              <ListItemIcon>
                <CoolCheckbox
                  edge="start"
                  checked={checked.indexOf(task.id) !== -1}
                  tabIndex={-1}
                  disableRipple
                  inputProps={{ 'aria-labelledby': labelId }}
                />
              </ListItemIcon>
              <ListItemText id={labelId} primary={task.name} />
            </ListItemButton>
          </ListItem>
        );
      })}
    </List>
  );
}
